@@ -19,4 +19,4 @@ def multiply(a: float = 1, b: float = 2):
 
 
 if __name__ == "__main__":
-    submit_job(__file__, output="data.json", method="local")
+    submit_job(__file__, output="data.json", method="foreground")
